<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL: https://svn.osuosl.org/public/maintain-project/branches/maintain-3/class/dao/extended/option.php $
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |       
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Author(s): Daniel Robert <robert@osuosl.org>                           |
// +------------------------------------------------------------------------+
// $Id: option.php 4779 2006-08-24 22:37:07Z wenzel $

/**
  * option.php - contains the {@link Option} class
  *
  * @author $Author: wenzel $
  * @filesource
  * @package    classes
  * @subpackage dao
  */

require_once DAODIR."/Object_option.php";

/**
  * This class represents a DHCP option for either a host, workgroup, or subnet
  *
  * @package    classes
  * @subpackage dao
  */
class Option extends DAO_Object_option {

    // {{{ constructor

    /**
      * Constructor
      *
      * @param  int Object_Option ID (primary key)
      */
	function Option ($option_id=0) 
    {
        if ($option_id) {
            $this->id = $option_id;
            $this->get($this->id);
        }

	} // Option

    // }}}

/* Setters */
    // {{{ setAll()
    function setAll()
    {
        $this->setType($this->type);
        $this->setScope($this->scope);
    }
    // }}}
    // {{{ setType()
    function setType($type)
    {
        if (!$type) {
            $this->type = 'host';
        } else {
            $this->type = $type;
        }

        return true;
    }
    // }}}
    // {{{ setScope()
    function setScope($scope)
    {
        if (!$scope) {
            $this->scope = 'host';
        } else {
            $this->scope = $scope;
        }
        return true;
    }
    // }}}
//{{{ getDisplay()
    /*
     *  Display string for some forms 
     */
    function getDisplay()
    {
        if (class_exists($this->type))  {
            $o = new $this->type($this->object_id);
            return $o->name;
        }
    }
//}}}
/* Built-In Methods */
    // {{{ has_access()

    /**
      * Make sure specified user has sufficient permissions to modify this option
      *
      * @param  string  username
      * @return boolean true if user has access to object
      */
	function has_access($username) 
    {
        switch (strtolower($this->type)) {

        case 'workgroup':
            $object = new Workgroup($this->object_id);
            break;

        case 'host':
            $object = new Host($this->object_id);
            break;

        // return false by default as a safety measure
        default:
            return false;

        } // switch

        return $object->has_access($username);
		
	} // has_access

    // }}}

/* Validators */
    // {{{ validateDhcp_option()

    /**
      * Validate the DHCP Option
      *
      * Note: This method is NOT internationalized in ANY way
      *
      * @return mixed   true on success, error string on failure
      */
    function validateDhcp_option()
    {
		global $conf;

        // some universal validation methods
        if (preg_match("/\"/", $this->value)) {
            $msg = _("Double quotes are not valid.").'  ';
            $msg .= _("They will be added as needed at build time.");
            return $msg;
        }

        // let's get the name of the option
        $dbdo = DB_DataObject::Factory('dhcp_options');
        $dbdo->get('id', $this->dhcp_option);
        $name = strtolower($dbdo->name);
        unset($dbdo);

        // cue up the standard error message 
        $msg = _("Value for")." $name ";

		switch ($name) {

        case 'always-reply-rfc1048':
            if (strcasecmp($this->value, 'on') || strcasecmp($this->value, 'off')) {
                return $msg . _("must be 'On' or 'Off'");
            }
            break;

        case 'netbios-node-type':
            $ok_vals = array(1,2,4,8);

            if (!in_array($this->value, $ok_vals)) {
                return $msg . _("must be 1, 2, 4, or 8");
            }
            break;

        case 'default-ip-ttl':
        case 'default-tcp-ttl':
        case 'time-offset':
        case 'min-lease-time':
        case 'max-lease-time':
        case 'default-lease-time':
            if (!is_numeric($this->value)) {
                return $msg . _("must be numeric");
            }
            break;

        case 'domain-name-servers':
        case 'broadcast-address':
        case 'routers':

            $data = explode(",", $this->value);
            foreach ($data as $ip_addr) {
                $ip_addr = trim($ip_addr);
                if (!preg_match("/\%[hi]{1}/", $ip_addr) &&
                        IP::is_dotted_quad($ip_addr)) {
                    continue;
                }
                else
                    return $msg . _("must be comma-separated list of dotted quads");
            }

            break;

        case 'ntp-servers':
        case 'swap-server':
        case 'nisplus-servers':
        case 'nntp-server':
        case 'pop-server':
        case 'resource-location-servers':
        case 'root-path':
        case 'smtp-server':
        case 'nds-servers':
        case 'cookie-servers':
        case 'netbios-name-servers':
        case 'netbios-dd-server':
        case 'www-server':
        case 'x-display-manager':
        case 'time-servers':
        case 'finger-server':
        case 'font-servers':
        case 'nis-servers':
        case 'impress-servers':
        case 'irc-server':
        case 'lpr-servers':
        case 'log-servers':

            $data = explode(",", $this->value);
            foreach ($data as $ip_addr) {
                // normalize the address
                $ip_addr = trim($ip_addr);

                if (!preg_match("/\%[hi]{1}/", $ip_addr) &&
                        IP::is_dotted_quad($ip_addr) &&
                        Domain::is_valid_name($this->value, true)) {
                    return $msg . _("must be a list of dotted quads and/or hostnames");
                }
            } //foreach
            break;

        case 'subnet-mask':

            $data = explode(",", $this->value);
            $subnet_values = array ('255','254','252','248','240','224','192','128','0');

            foreach ($data as $ip_addr) {
                // normalize ip addresses
                $ip_addr = trim($ip_addr);

                $quads = explode(".",$ip_addr);
                foreach($quads as $quad_value) {

                    // normalize the quad value
                    $quad_value = trim($quad_value);

                    // make sure value is not in the subnet_values list
                    if (!in_array($quad_value,$subnet_values)) {
                        $msg .= _("must not be in this list:").' ';
                        $msg .= implode(',', $subnet_values);
                        return $msg;
                    }
                } // end foreach quads

                if (!IP::is_dotted_quad($ip_addr)) {
                    return $msg . _("format must be dotted quad");
                }

            } // for each IP address

            break;

        case 'domain-name':
            if (preg_match("/\%[h]{1}/",$this->value)) { $valid = true; }
            if (!Domain::is_valid_name($this->value, true) && !$valid) {
                return _("Invalid Domain.");
            } 
            break;

        case 'nds-context':
        case 'nds-tree-name':
        case 'nisplus-domain':

            if (!preg_match("/^[\w\d\s\.\-]+$/",$this->value)) {
                return _("Invalid string");
            }
            break;

        case 'static-routes':
            $data = explode(",", $this->value);

            foreach ($data as $ip_route) {
                $ip_route = trim($ip_route);

                if (!preg_match("/^\%[him]{1}$/",trim($ip_addr))) { $valid = true; }
                if (!preg_match("/^\%[him]{1}$/", $ip_route) &&
                        preg_match("/^(\d{1,3}\.){3}\d{1,3}\s(\d{1,3}\.)\d{1,3}$/")) {

                    $msg .= _("format should be a list of white-space separated dotted quads");
                    $msg .= ' '._("where each list entry is separated by commas").' ';
                    $msg .= _("For example: 10.0.0.1 10.0.1.1, 10.0.0.20 10.0.0.25");
                    return $msg;
                }
            } //foreach static route

            break;

        case 'dhcp-parameter-request-list':
            if (!is_int($this->value)) {
                return $msg . _("must be an integer");
            }

            break;

		} // end switch on dhcp_option
        return true;

	} // validateDhcp_option

    // }}}
    // {{{ validateScope()

    function validateScope()
    {
        // for non-workgroup scopes, the scope should equal the type
        if (strtolower($this->type) !== 'workgroup') {
            if ($this->type === $this->scope)
                return true;
            else
                return _("Option scope must match the type");
        }

        // for workgroups, the scope can be 'workgroup' or 'host'
        if ($this->scope === 'workgroup' || $this->scope === 'host')    {
            return true;
        }
        else    {
            return _("Option for workgroup must be either 'host' or 'workgroup'");
        }

	}

    // }}}

/* Internal Methods */
    // {{{ _history_text()

    function _history_text()
    {
        return $this->getValue();
    }

    // }}}

} // class Option

?>
