<?php
/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL: https://svn.osuosl.org/public/maintain-project/branches/maintain-3/class/htdocs/datalist/HostDataList.php $
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Authors: Daniel Robert <robert@osuosl.org>                             |
// |          Frederic Wenzel <fred@osuosl.org>                             |
// |          Zack Bartel <bartel@osuosl.org>                               |
// +------------------------------------------------------------------------+
   
// $Id: HostDataList.php 4717 2006-08-09 22:47:42Z schonstal $

/**
  * HostDataList.php - contains the {@link HostDataList} class
  *
  * @author $Author: schonstal $
  * @filesource
  * @package    htdocs
  * @subpackage datalists
  */

require_once(DAOEXT.'/host.php');
require_once(HTCLASS.'/DB_DataObjectDataList.php');
require_once(HTCLASS.'/DB_DataObjectDataListSource.php');

/**
  * Table listing of Hosts
  *
  * @link   http://phphtmllib.newsblob.com/javadoc.php phpHtmlLib API Documentation
  * @link   http://phphtmllib.newsblob.com/doc/phpHtmlLib/DefaultGUIDatalist.html
            DefaultGUIDataList API Documentation
  * @package    htdocs
  * @subpackage datalists
  */
class HostDataList extends DB_DataObjectDataList
{

// {{{ vars
    // convert the search value to int when searching for ips?
    var $search_convert_ip2int = false;
// }}}

// {{{ get_data_source()

    function get_data_source()
    {
        $host = new Host();
        $src = &new DB_DataObjectDataListSource($host);
        $this->set_data_source($src);
    }

// }}}
// {{{ _user_setup()

    function _user_setup()
    {
        $this->set_actionbar(true);

        // add a checkbox column
        $this->add_action_column('checkbox', 'FIRST', 'id');
        $this->set_checkboxvar('hostlist');

        // set up the columns
        $this->add_header_item(_("Hostname"), '20%', 'name', SORTABLE, SEARCHABLE);
        $this->add_header_item(_("IP Addr"), '20%', 'ip', SORTABLE, SEARCHABLE);
        $this->add_header_item(_("Last Seen"), '20%', 'last_seen', SORTABLE);
        $this->add_header_item(_("OS"),'20%','os',SORTABLE);
        $this->add_header_item(_("Action"),'20%');


        /* Error in this: 
            $this->_datasource->setup_db_options(array('zone' => $_SESSION['zone']));
            if we do $host->setZone(zone) then it will in turn set the workgroup to
            the defautl workgroup for that zone (if zone != $host->zone). In this
            case of searching that would limit our search to hosts in this zone and
            with the default workgroup which is not what we want (we want all hosts
            in the zone).
        */

            $this->_datasource->setup_db_options(array('zone' => $_SESSION['zone']));
        //$this->_datasource->_dbdo->zone = $_SESSION['zone'];
        unset($this->_save_vars['action']);

    }

// }}}
// {{{ build_column_item()

    function build_column_item($row_data, $col_name)
    {
        switch ($col_name)
        {
            case _('Hostname'):
                $link = web_root().'host.php?action=show&amp;id='.$row_data['id'];
                $obj = html_a($link, $row_data[_('hostname')]);
                break;
            case _('IP Addr'):
                $obj = $row_data['ip'];
                if($obj == 0) {
                    $obj = $row_data['dynamic_range'];
                }
                break;
            case _('Action'):
                $obj = container();
                $obj = Module::apply_filter('action_module', $obj, $row_data, 'host');
                break;
            default:
                $obj = parent::build_column_item($row_data, $col_name);
        }

        return $obj;
    }

// }}}

// {{{ data_prefetch()
/**
  * data_prefetch queries the database.
  * This is a wrapper for the actual data_prefetch function in order to
  * translate the ip field to int format if we are currently running
  * an ip search.
  * Otherwise we just pass through the parent function.
  */
    function data_prefetch()
    {
        if ($this->search_field() == 'ip') {
            $this->search_convert_ip2int = true;
            parent::data_prefetch();
            $this->search_convert_ip2int = false;
            
        } else {
            parent::data_prefetch();
        }
    }

// }}}
// {{{ search_value()
/**
  * overriding parent search_value: to search for ips, we need to translate them
  * from dotted quad to int format before we query the database.
  * This should only happen for the database, not for displaying, which is
  * why the flag search_convert_ip2int will only be set temporarily by
  * data_prefetch().
  * In all other cases, we just pass through the parent search_value function.
  */
    function search_value()
    {
        // convert ip to int representation for ip search?
        if ($this->search_convert_ip2int && $this->search_field() == "ip") {
            return Net_IPv4::ip2double(parent::search_value());
        } else {
            return parent::search_value();
        }
    }
    
// }}}
// {{{ actionbar_cell()

    function actionbar_cell()
    {
        global $user;
        
        $container = container();
        $button  = html_input('submit', 'action', _('Bulk Host Delete'));
        $button2 = html_input('submit', 'action', _('Bulk Host Update'));
        $button3 = html_input('submit', 'action', _('Bulk Host Zone Move'));
        $button4 = html_input('submit', 'action', _('Host Batch Move'));
        $button5 = html_input('submit', 'action', _('Host Batch Copy'));
        $container->add($button, $button2, $button3, $button4, $button5);

        return $container;
    }

// }}}

}

?>
