<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 foldmethod=marker: */
// $HeadURL: https://svn.osuosl.org/public/maintain-project/branches/maintain-3/htdocs/user.php $
// +------------------------------------------------------------------------+
// | Maintain - DNS/DHCP Managment Tool                                     |
// +------------------------------------------------------------------------+
// | Copyright (c) 2004 Open Source University                              |
// +------------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or          |
// | modify it under the terms of the GNU General Public License            |
// | as published by the Free Software Foundation; either version 2         |
// | of the License, or (at your option) any later version.                 |
// |                                                                        |
// | This program is distributed in the hope that it will be useful,        |
// | but WITHOUT ANY WARRANTY; without even the implied warranty of         |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          |
// | GNU General Public License for more details.                           |
// |                                                                        |
// | You should have received a copy of the GNU General Public License      |
// | along with this program; if not, write to the Free Software            |
// | Foundation, Inc., 59 Temple Place - Suite 330,                         |
// | Boston, MA  02111-1307, USA.                                           |
// +------------------------------------------------------------------------+
// | Authors: Michael Clay <claym@osuosl.org>                               |
// +------------------------------------------------------------------------+
// $Id: user.php 4758 2006-08-18 21:37:02Z schonstal $

/**
  * User Configuration Page
  *
  * @package    htdocs
  */

require_once("includes.php");
require_once(HTCLASS."/datalist/UserDataList.php");
require_once(HTCLASS."/datalist/ZoneUserDataList.php");
require_once(FORMDIR."/UserAddForm.php");
require_once(FORMDIR."/DeleteZoneUserConfirm.php");
require_once(FORMDIR."/FullAdminForm.php");
require_once(FORMDIR."/ZoneUserAddForm.php");
require_once(FORMDIR."/PreferencesForm.php");
require_once(FORMDIR."/UserDeleteConfirm.php");


//Establish the user and start the session
session_start();
setup_user_environment();

$skin = Skin::Factory($user->color_template);

$title = html_span("title");

$content = container();

//React to what we're doing
switch(strtolower($_REQUEST['action'])) {

case 'fulladmin': //Adding a full admin
    if(!$user->is_admin())
        header("Location: denied.php");
    $title->add(_("Make User a Full Admin"));
    $content->add($title);
    
    $faf = new FormProcessor(new FullAdminForm(), "fulladd");
    $faf->set_render_form_after_success(false);
    $content->add($faf);
    break;

case 'create': //adding a new user
    if(!$user->is_admin())
        header("Location: denied.php");
    $title->add(_("Add a New User"));
    $content->add($title);
    
    $uaf = new FormProcessor(new UserAddForm(), "useradd");
    $content->add($uaf);
    break;
    
case 'delzoneuser': //deleting a user from a zone
    if(!$user->is_admin())
        header("Location: denied.php");
    $title->add(_("Are you sure?"));
    $dzuc = new FormProcessor(new DeleteZoneUserConfirm(), "deluser");
    $dzuc->set_render_form_after_success(false);
    $content->add($dzuc);
    break;

case 'show_add':
    if(!$user->is_zone_admin($zone)) 
        header("Location: denied.php");
    $title->add(_("Add User to Zone"));
    $content->add($title);

    $uaf = new FormProcessor(new ZoneUserAddForm, "addzoneuser");
    $uaf->set_render_form_after_success(false);
    $content->add($uaf);
    break;

/* Deleting a user totally */
case 'delete':
    if (!$user->is_admin())
        header("Location: denied.php");

    $title->add(_("Deleting User"));
    $content->add($title);
    $ud = new FormProcessor(new UserDeleteConfirm, 'userdel');
    $ud->set_render_form_after_success(false);
    $content->add($ud);
    break;

case 'setlevel': //changing an access level
    if(!$user->is_admin($zone))
        header("Location: denied.php");
    $usr = DB_DataObject::Factory('zone_user');
    $usr->zone = $_REQUEST['zone_id'];
    $usr->username = $_REQUEST['name'];
    $usr->find(1);
    $usr->level = $_REQUEST['level'];

    if($usr->update() !== false) {
        $zn = new Zone($_REQUEST['zone_id']);
        $msg = "User ". $_REQUEST['name']." access level changed to ". 
                        User::access_level($_REQUEST['level']);
        $zn->write_history($msg, $user->username);
        $span = html_span("success");
        $span->add($msg);
        $content->add($span);
    } else {
        $span = html_span("error");
        $span->add("Failed to update user permission level!");
        $content->add($span);
    }

case 'show': //showing the page
case 'edit':

default: //show the page by default
    $title->add(_("User information"));

    if (isset($_REQUEST['username']))   {
        if(!$user->is_admin($zone) && strcasecmp($_REQUEST['username'],$user->username))
            header("Location: denied.php");
        $d = new FormProcessor(new PreferencesForm(), 'prefform');
        $content->add($d);
        break;
    }
    $content->add($title);
    
    if(!strcasecmp($_REQUEST['type'],'zone')) {
        if(!$user->is_zone_admin($zone))
            header("Location: denied.php");
        $ul = new ZoneUserDataList(_("Users"));
    } else {
        if(!$user->is_admin($zone))
            header("Location: denied.php");
        $ul = new UserDataList(_("Users"));
    }
    $content->add($ul);
    break;
}

print $skin->display($content);

?>
